@@ -72,22 +72,23 @@ use constant STATUS_UNAVAILABLE => -2;
 use constant PROCESS_PKGS_ONLY => 1;
 use constant PROCESS_PKGS_AND_DEPS => 2;
 
-use constant NONE => 0b00000000;
-use constant ALL => 0b00001111;
-use constant SELECTED => 0b00011111;
-use constant NEW => 0b00001000;
-use constant NOT_NEW => 0b00000111;
-use constant UPDATED => 0b00000100;
-use constant NOT_UPDATED => 0b00001011;
-use constant INSTALLED => 0b00000010;
-use constant NOT_INSTALLED => 0b00001101;
-use constant DOWNGRADED => 0b00000001;
-use constant NOT_DOWNGRADED => 0b00001110;
-# MODIFIED = UPDATED | DOWNGRADED
-use constant MODIFIED => 0b00000101;
-use constant NOT_MODIFIED => 0b00001010;
-use constant ORPHANS => 0b00010000;
-use constant NOT_ORPHANS => 0b00001111;
+use constant NONE => 			0b00000000;
+use constant ALL => 			0b11111111;
+use constant NEW => 			0b00001000;
+use constant NOT_NEW => 		0b11110111;
+use constant UPDATED => 		0b00000100;
+use constant NOT_UPDATED => 	0b11111011;
+use constant INSTALLED => 		0b00000010;
+use constant NOT_INSTALLED => 	0b11111101;
+use constant DOWNGRADED => 		0b00000001;
+use constant NOT_DOWNGRADED => 	0b11111110;
+use constant MODIFIED => 		0b00000101;
+use constant NOT_MODIFIED => 	0b11111010;
+use constant ORPHANS => 		0b00010000;
+use constant NOT_ORPHANS => 	0b11101111;
+use constant SHOW_EXTRA => 		0b00100000;
+use constant NOT_SHOW_EXTRA => 	0b11011111;
+
 
 use constant ICON_COLUMN => 0;
 use constant SOFT_COLUMN => 1;
@@ -181,7 +182,7 @@ sub LoadDB {
 }
 
 # Will parse the repository data to fill %db related fields
-# $href = $Netpkg->BuildDB
+# $href = $Netpkg->BuildDB(\%db)
 sub BuildDB {
 	my $self = shift; 
 	my %db = [];
@@ -267,98 +268,10 @@ sub BuildDB {
 	return \%db;
 }
 
-####################################################################
-# Will set categories according to the origin of package
-sub SetCategories {
-	my $self = shift; 
-	my %db = %{$_[0]};
-	my $soft;
-	for $soft ( keys %db ) {
-		if ( 
-		@{$db{$soft}}[PATH] =~ /^l$/ || 
-		@{$db{$soft}}[PATH] =~ /.*\/l$/ 
-		) {
-			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Runtime libraries"));
-			@{$db{$soft}}[CATEGORY_ICON] = "gnome-other";
-		}elsif ( 
-		@{$db{$soft}}[PATH] =~ /^d$/ ||
-		@{$db{$soft}}[PATH] =~ /.*\/d$/ 
-		) {
-			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Development libraries"));
-			@{$db{$soft}}[CATEGORY_ICON] = "development";
-		}elsif ( 
-		@{$db{$soft}}[PATH] =~ /^x$/ ||
-		@{$db{$soft}}[PATH] =~ /.*\/x$/ 
-		) {
-			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Xorg"));
-			@{$db{$soft}}[CATEGORY_ICON] = "xorg";
-		}elsif ( 
-		@{$db{$soft}}[PATH] =~ /^ap$/ ||
-		@{$db{$soft}}[PATH] =~ /.*\/ap$/
-		) {
-			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Console Applications"));
-			@{$db{$soft}}[CATEGORY_ICON] = "utilities-terminal";
-		}elsif ( 
-		@{$db{$soft}}[PATH] =~ /^xap$/ ||
-		@{$db{$soft}}[PATH] =~ /.*\/xap$/
-		) {
-			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Graphical Applications"));
-			@{$db{$soft}}[CATEGORY_ICON] = "applications-graphics";
-		}elsif ( 
-		@{$db{$soft}}[PATH] =~ /.*\/g$/ 
-		) {
-			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Gnome Desktop"));
-			@{$db{$soft}}[CATEGORY_ICON] = "gnome-logo";
-		}elsif ( 
-		@{$db{$soft}}[PATH] =~ /.*\/kde$/ 
-		) {
-			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("KDE Desktop"));
-			@{$db{$soft}}[CATEGORY_ICON] = "konqueror";
-		}elsif ( 
-		@{$db{$soft}}[PATH] =~ /^a$/ || 
-		@{$db{$soft}}[PATH] =~ /.*\/a$/ 
-		) {
-			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("System"));
-			@{$db{$soft}}[CATEGORY_ICON] = "applications-system";
-		}elsif ( 
-		@{$db{$soft}}[PATH] =~ /^locale$/ || 
-		@{$db{$soft}}[PATH] =~ /.*\/locale$/ 
-		) {
-			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Localization"));
-			@{$db{$soft}}[CATEGORY_ICON] = "preferences-desktop-locale";
-		}elsif ( 
-		@{$db{$soft}}[PATH] =~ /^games$/ || 
-		@{$db{$soft}}[PATH] =~ /.*\/games$/ 
-		) {
-			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Games"));
-			@{$db{$soft}}[CATEGORY_ICON] = "applications-games";
-		}elsif ( 
-		@{$db{$soft}}[PATH] =~ /^patches$/ || 
-		@{$db{$soft}}[PATH] =~ /.*\/patches$/ 
-		) {
-			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Patches"));
-			@{$db{$soft}}[CATEGORY_ICON] = "administration";
-		}elsif ( 
-		@{$db{$soft}}[PATH] =~ /^n$/ || 
-		@{$db{$soft}}[PATH] =~ /.*\/n$/ ||
-		@{$db{$soft}}[PATH] =~ /^s$/ || 
-		@{$db{$soft}}[PATH] =~ /.*\/s$/ 
-		) {
-			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Network"));
-			@{$db{$soft}}[CATEGORY_ICON] = "applications-internet";
-		}else{
-			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Misc"));
-			@{$db{$soft}}[CATEGORY_ICON] = "applications-other";
-		}
-			
-		@{$db{$soft}}[UID] = @{$db{$soft}}[CATEGORY].$soft.@{$db{$soft}}[AVAILABLE_VERSION].@{$db{$soft}}[AVAILABLE_BUILD].@{$db{$soft}}[INSTALLED_VERSION].@{$db{$soft}}[INSTALLED_BUILD];							
-	}
-	#return \%db;
-}
 
 ####################################################################
 # Will check installed packages to fill %db related fields
-# $Netpkg->CheckInstalledPkgs(\%db)
+# $href = $Netpkg->CheckInstalledPkgs(\%db)
 sub CheckInstalledPkgs {
 	my $self = shift; 
 	my %db = %{$_[0]};
@@ -437,6 +350,102 @@ sub CheckInstalledPkgs {
 	return \%db;;
 }
 
+####################################################################
+# Will set categories according to the origin of package
+# $href = $Netpkg->SetCategories(\%db)
+sub SetCategories {
+	my $self = shift; 
+	my %db = %{$_[0]};
+	my $soft;
+	for $soft ( keys %db ) {
+		
+		if ( @{$db{$soft}}[AVAILABLE_VERSION] eq "" ||  @{$db{$soft}}[INSTALLED_VERSION] eq "" ) {
+			delete($db{$soft});
+			next;
+		}				
+		
+		if ( 
+		@{$db{$soft}}[PATH] =~ /^l$/ || 
+		@{$db{$soft}}[PATH] =~ /.*\/l$/ 
+		) {
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Runtime libraries"));
+			@{$db{$soft}}[CATEGORY_ICON] = "gnome-other";
+		}elsif ( 
+		@{$db{$soft}}[PATH] =~ /^d$/ ||
+		@{$db{$soft}}[PATH] =~ /.*\/d$/ 
+		) {
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Development libraries"));
+			@{$db{$soft}}[CATEGORY_ICON] = "development";
+		}elsif ( 
+		@{$db{$soft}}[PATH] =~ /^x$/ ||
+		@{$db{$soft}}[PATH] =~ /.*\/x$/ 
+		) {
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Xorg"));
+			@{$db{$soft}}[CATEGORY_ICON] = "xorg";
+		}elsif ( 
+		@{$db{$soft}}[PATH] =~ /^ap$/ ||
+		@{$db{$soft}}[PATH] =~ /.*\/ap$/
+		) {
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Console Applications"));
+			@{$db{$soft}}[CATEGORY_ICON] = "utilities-terminal";
+		}elsif ( 
+		@{$db{$soft}}[PATH] =~ /^xap$/ ||
+		@{$db{$soft}}[PATH] =~ /.*\/xap$/
+		) {
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Graphical Applications"));
+			@{$db{$soft}}[CATEGORY_ICON] = "applications-graphics";
+		}elsif ( 
+		@{$db{$soft}}[PATH] =~ /.*\/g$/ 
+		) {
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Gnome Desktop"));
+			@{$db{$soft}}[CATEGORY_ICON] = "gnome-logo";
+		}elsif ( 
+		@{$db{$soft}}[PATH] =~ /.*\/kde$/ 
+		) {
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("KDE Desktop"));
+			@{$db{$soft}}[CATEGORY_ICON] = "konqueror";
+		}elsif ( 
+		@{$db{$soft}}[PATH] =~ /^a$/ || 
+		@{$db{$soft}}[PATH] =~ /.*\/a$/ 
+		) {
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("System"));
+			@{$db{$soft}}[CATEGORY_ICON] = "applications-system";
+		}elsif ( 
+		@{$db{$soft}}[PATH] =~ /^locale$/ || 
+		@{$db{$soft}}[PATH] =~ /.*\/locale$/ 
+		) {
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Localization"));
+			@{$db{$soft}}[CATEGORY_ICON] = "preferences-desktop-locale";
+		}elsif ( 
+		@{$db{$soft}}[PATH] =~ /^games$/ || 
+		@{$db{$soft}}[PATH] =~ /.*\/games$/ 
+		) {
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Games"));
+			@{$db{$soft}}[CATEGORY_ICON] = "applications-games";
+		}elsif ( 
+		@{$db{$soft}}[PATH] =~ /^patches$/ || 
+		@{$db{$soft}}[PATH] =~ /.*\/patches$/ 
+		) {
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Patches"));
+			@{$db{$soft}}[CATEGORY_ICON] = "administration";
+		}elsif ( 
+		@{$db{$soft}}[PATH] =~ /^n$/ || 
+		@{$db{$soft}}[PATH] =~ /.*\/n$/ ||
+		@{$db{$soft}}[PATH] =~ /^s$/ || 
+		@{$db{$soft}}[PATH] =~ /.*\/s$/ 
+		) {
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Network"));
+			@{$db{$soft}}[CATEGORY_ICON] = "applications-internet";
+		}else{
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Misc"));
+			@{$db{$soft}}[CATEGORY_ICON] = "applications-other";
+		}
+			
+		@{$db{$soft}}[UID] = @{$db{$soft}}[CATEGORY].$soft.@{$db{$soft}}[AVAILABLE_VERSION].@{$db{$soft}}[AVAILABLE_BUILD].@{$db{$soft}}[INSTALLED_VERSION].@{$db{$soft}}[INSTALLED_BUILD];	
+							
+	}
+	return \%db;
+}
 
 ####################################################################
 # $Netpkg->GetFilters();
